{pkgs, ...}:
{
	imports = [./default.nix];

 	home.sessionVariables = {
		NIXOS_OZONE_WL = "1";
		BROWSER = "firefox";
		GDK_BACKEND = "wayland";
		MOZ_ENABLE_WAYLAND = "1";
		MOZ_WEBRENDER = "1";
	};

	fonts.fontconfig.enable = true;

	home.packages = with pkgs; [
		# env
		libnotify
		mpv
		pavucontrol
		# glib gsettings-desktop-schemas - # run gsettings for gnome
		noto-fonts
		noto-fonts-emoji
		powerline-fonts
		line-awesome
		yubikey-manager
		# yubikey-personalization
		pinentry-gnome
		# dbus
		gcr
		dconf
		# gotify-desktop # use ntfy.sh instatt
		# apps
		virt-manager
		openlens
		evince
		gthumb
		gnome.seahorse
		gnome.cheese
		nextcloud-client
		dino # xmpp
		onlyoffice-bin
		libreoffice-fresh
		inkscape
		gimp
		homebank
		# ahnen
		(gramps.override {
			enableOSM = true;
			enableGraphviz = true;
			enableGhostscript = true;
		#	pythonPath = [ pythonPackages.keyring ];
		})
		python310Packages.keyring
		graphviz-nox
		tootle # mastodon
		# fractal # matrix
		fractal-next
		fluffychat
		cozy # audiobooks
	];
	gtk = {
		enable = true;
		theme = {
			# package = pkgs.yaru-theme;
			# name = "Yaru-dark";

			package = pkgs.flat-remix-gtk;
			name = "Flat-Remix-GTK-Blue-Darkest";
			# name = "Flat-Remix-GTK-Blue-Darkest-NoBorder";
			# name = "Flat-Remix-GTK-Blue-Darker";
		};
		iconTheme = {
			package = pkgs.yaru-theme;
			name = "Yaru";

			# package = pkgs.flat-remix-icon-theme;
			# name = "Flat-Remix-Violet-Dark";
		};
	};
	programs.gpg = {
		enable = true;
		scdaemonSettings = {
			disable-ccid = true;
		};
		settings = {
			keyserver = "hkps://keys.openpgp.org";
		};
	};
	services.gnome-keyring.enable = true;
	services.gpg-agent = {
		enable = true;
		enableSshSupport = true;
		pinentryFlavor = "gnome3";
	};


	programs.browserpass = {
		enable = true;
		browsers = ["firefox"];
	};
	programs.librewolf = {
		enable = false;
		settings = {
			"privacy.clearOnShutdown.history" = false;
			"privacy.clearOnShutdown.downloads" = false;
			"browser.sessionstore.privacy_level" = 0;
		};
	};
	programs.firefox = {
		enable = true;
		# nixos not home-manager
		# nativeMessagingHosts = {
		#	fxCast = true;
		#};
		# package = pkgs.firefox-beta-bin;
	#	# package = pkgs.firefox-devedition-bin;
		# package = pkgs.librewolf;
	};
	programs.thunderbird = {
	  enable = true;
		package = pkgs.thunderbird-wayland;
		settings = {
		  "general.useragent.override" = "";
			"privacy.donottrackheader.enabled" = true;
		};
		profiles.default = {
			isDefault = true;
			withExternalGnupg = true;
		};
	};
}
